# -*- coding: utf-8 -*-
"""`ISIC31 Standard <https://unstats.un.org/unsd/classifications/Econ/Download/In%20Text/ISIC_Rev_3_1_english_structure.txt>`_.
"""
from ...types import Category, Classification, Standard, Standards

ISIC31 = Standard(
    standard=Standards.ISIC31,
    classes=[
        Classification("A", "Agriculture, hunting and forestry", Category.SECTION),
        Classification("01", "Agriculture, hunting and related service activities", Category.DIVISION),
        Classification("011", "Growing of crops; market gardening; horticulture", Category.GROUP),
        Classification("0111", "Growing of cereals and other crops n.e.c.", Category.CLASS),
        Classification("0112", "Growing of vegetables, horticultural specialties and nursery products", Category.CLASS),
        Classification("0113", "Growing of fruit, nuts, beverage and spice crops", Category.CLASS),
        Classification("012", "Farming of animals", Category.GROUP),
        Classification(
            "0121", "Farming of cattle, sheep, goats, horses, asses, mules and hinnies; dairy farming", Category.CLASS
        ),
        Classification("0122", "Other animal farming; production of animal products n.e.c.", Category.CLASS),
        Classification("013", "Growing of crops combined with farming of animals (mixed farming)", Category.GROUP),
        Classification("0130", "Growing of crops combined with farming of animals (mixed farming)", Category.CLASS),
        Classification(
            "014", "Agricultural and animal husbandry service activities, except veterinary activities", Category.GROUP
        ),
        Classification(
            "0140", "Agricultural and animal husbandry service activities, except veterinary activities", Category.CLASS
        ),
        Classification(
            "015", "Hunting, trapping and game propagation including related service activities", Category.GROUP
        ),
        Classification(
            "0150", "Hunting, trapping and game propagation including related service activities", Category.CLASS
        ),
        Classification("02", "Forestry, logging and related service activities", Category.DIVISION),
        Classification("020", "Forestry, logging and related service activities", Category.GROUP),
        Classification("0200", "Forestry, logging and related service activities", Category.CLASS),
        Classification("B", "Fishing", Category.SECTION),
        Classification("05", "Fishing, aquaculture and service activities incidental to fishing", Category.DIVISION),
        Classification("050", "Fishing, aquaculture and service activities incidental to fishing", Category.GROUP),
        Classification("0501", "Fishing", Category.CLASS),
        Classification("0502", "Aquaculture", Category.CLASS),
        Classification("C", "Mining and quarrying", Category.SECTION),
        Classification("10", "Mining of coal and lignite; extraction of peat", Category.DIVISION),
        Classification("101", "Mining and agglomeration of hard coal", Category.GROUP),
        Classification("1010", "Mining and agglomeration of hard coal", Category.CLASS),
        Classification("102", "Mining and agglomeration of lignite", Category.GROUP),
        Classification("1020", "Mining and agglomeration of lignite", Category.CLASS),
        Classification("103", "Extraction and agglomeration of peat", Category.GROUP),
        Classification("1030", "Extraction and agglomeration of peat", Category.CLASS),
        Classification(
            "11",
            "Extraction of crude petroleum and natural gas; service activities incidental to oil and gas extraction, excluding surveying",
            Category.DIVISION,
        ),
        Classification("111", "Extraction of crude petroleum and natural gas", Category.GROUP),
        Classification("1110", "Extraction of crude petroleum and natural gas", Category.CLASS),
        Classification(
            "112", "Service activities incidental to oil and gas extraction excluding surveying", Category.GROUP
        ),
        Classification(
            "1120", "Service activities incidental to oil and gas extraction excluding surveying", Category.CLASS
        ),
        Classification("12", "Mining of uranium and thorium ores", Category.DIVISION),
        Classification("120", "Mining of uranium and thorium ores", Category.GROUP),
        Classification("1200", "Mining of uranium and thorium ores", Category.CLASS),
        Classification("13", "Mining of metal ores", Category.DIVISION),
        Classification("131", "Mining of iron ores", Category.GROUP),
        Classification("1310", "Mining of iron ores", Category.CLASS),
        Classification("132", "Mining of non-ferrous metal ores, except uranium and thorium ores", Category.GROUP),
        Classification("1320", "Mining of non-ferrous metal ores, except uranium and thorium ores", Category.CLASS),
        Classification("14", "Other mining and quarrying", Category.DIVISION),
        Classification("141", "Quarrying of stone, sand and clay", Category.GROUP),
        Classification("1410", "Quarrying of stone, sand and clay", Category.CLASS),
        Classification("142", "Mining and quarrying n.e.c.", Category.GROUP),
        Classification("1421", "Mining of chemical and fertilizer minerals", Category.CLASS),
        Classification("1422", "Extraction of salt", Category.CLASS),
        Classification("1429", "Other mining and quarrying n.e.c.", Category.CLASS),
        Classification("D", "Manufacturing", Category.SECTION),
        Classification("15", "Manufacture of food products and beverages", Category.DIVISION),
        Classification(
            "151",
            "Production, processing and preservation of meat, fish, fruit, vegetables, oils and fats",
            Category.GROUP,
        ),
        Classification("1511", "Production, processing and preserving of meat and meat products", Category.CLASS),
        Classification("1512", "Processing and preserving of fish and fish products", Category.CLASS),
        Classification("1513", "Processing and preserving of fruit and vegetables", Category.CLASS),
        Classification("1514", "Manufacture of vegetable and animal oils and fats", Category.CLASS),
        Classification("152", "Manufacture of dairy products", Category.GROUP),
        Classification("1520", "Manufacture of dairy products", Category.CLASS),
        Classification(
            "153",
            "Manufacture of grain mill products, starches and starch products, and prepared animal feeds",
            Category.GROUP,
        ),
        Classification("1531", "Manufacture of grain mill products", Category.CLASS),
        Classification("1532", "Manufacture of starches and starch products", Category.CLASS),
        Classification("1533", "Manufacture of prepared animal feeds", Category.CLASS),
        Classification("154", "Manufacture of other food products", Category.GROUP),
        Classification("1541", "Manufacture of bakery products", Category.CLASS),
        Classification("1542", "Manufacture of sugar", Category.CLASS),
        Classification("1543", "Manufacture of cocoa, chocolate and sugar confectionery", Category.CLASS),
        Classification(
            "1544", "Manufacture of macaroni, noodles, couscous and similar farinaceous products", Category.CLASS
        ),
        Classification("1549", "Manufacture of other food products n.e.c.", Category.CLASS),
        Classification("155", "Manufacture of beverages", Category.GROUP),
        Classification(
            "1551",
            "Distilling, rectifying and blending of spirits; ethyl alcohol production from fermented materials",
            Category.CLASS,
        ),
        Classification("1552", "Manufacture of wines", Category.CLASS),
        Classification("1553", "Manufacture of malt liquors and malt", Category.CLASS),
        Classification("1554", "Manufacture of soft drinks; production of mineral waters", Category.CLASS),
        Classification("16", "Manufacture of tobacco products", Category.DIVISION),
        Classification("160", "Manufacture of tobacco products", Category.GROUP),
        Classification("1600", "Manufacture of tobacco products", Category.CLASS),
        Classification("17", "Manufacture of textiles", Category.DIVISION),
        Classification("171", "Spinning, weaving and finishing of textiles", Category.GROUP),
        Classification("1711", "Preparation and spinning of textile fibres; weaving of textiles", Category.CLASS),
        Classification("1712", "Finishing of textiles", Category.CLASS),
        Classification("172", "Manufacture of other textiles", Category.GROUP),
        Classification("1721", "Manufacture of made-up textile articles, except apparel", Category.CLASS),
        Classification("1722", "Manufacture of carpets and rugs", Category.CLASS),
        Classification("1723", "Manufacture of cordage, rope, twine and netting", Category.CLASS),
        Classification("1729", "Manufacture of other textiles n.e.c.", Category.CLASS),
        Classification("173", "Manufacture of knitted and crocheted fabrics and articles", Category.GROUP),
        Classification("1730", "Manufacture of knitted and crocheted fabrics and articles", Category.CLASS),
        Classification("18", "Manufacture of wearing apparel; dressing and dyeing of fur", Category.DIVISION),
        Classification("181", "Manufacture of wearing apparel, except fur apparel", Category.GROUP),
        Classification("1810", "Manufacture of wearing apparel, except fur apparel", Category.CLASS),
        Classification("182", "Dressing and dyeing of fur; manufacture of articles of fur", Category.GROUP),
        Classification("1820", "Dressing and dyeing of fur; manufacture of articles of fur", Category.CLASS),
        Classification(
            "19",
            "Tanning and dressing of leather; manufacture of luggage, handbags, saddlery, harness and footwear",
            Category.DIVISION,
        ),
        Classification(
            "191",
            "Tanning and dressing of leather; manufacture of luggage, handbags, saddlery and harness",
            Category.GROUP,
        ),
        Classification("1911", "Tanning and dressing of leather", Category.CLASS),
        Classification("1912", "Manufacture of luggage, handbags and the like, saddlery and harness", Category.CLASS),
        Classification("192", "Manufacture of footwear", Category.GROUP),
        Classification("1920", "Manufacture of footwear", Category.CLASS),
        Classification(
            "20",
            "Manufacture of wood and of products of wood and cork, except furniture; manufacture of articles of straw and plaiting materials",
            Category.DIVISION,
        ),
        Classification("201", "Sawmilling and planing of wood", Category.GROUP),
        Classification("2010", "Sawmilling and planing of wood", Category.CLASS),
        Classification("202", "Manufacture of products of wood, cork, straw and plaiting materials", Category.GROUP),
        Classification(
            "2021",
            "Manufacture of veneer sheets; manufacture of plywood, laminboard, particle board and other panels and boards",
            Category.CLASS,
        ),
        Classification("2022", "Manufacture of builders' carpentry and joinery", Category.CLASS),
        Classification("2023", "Manufacture of wooden containers", Category.CLASS),
        Classification(
            "2029",
            "Manufacture of other products of wood; manufacture of articles of cork, straw and plaiting materials",
            Category.CLASS,
        ),
        Classification("21", "Manufacture of paper and paper products", Category.DIVISION),
        Classification("210", "Manufacture of paper and paper products", Category.GROUP),
        Classification("2101", "Manufacture of pulp, paper and paperboard", Category.CLASS),
        Classification(
            "2102",
            "Manufacture of corrugated paper and paperboard and of containers of paper and paperboard",
            Category.CLASS,
        ),
        Classification("2109", "Manufacture of other articles of paper and paperboard", Category.CLASS),
        Classification("22", "Publishing, printing and reproduction of recorded media", Category.DIVISION),
        Classification("221", "Publishing", Category.GROUP),
        Classification("2211", "Publishing of books, brochures and other publications", Category.CLASS),
        Classification("2212", "Publishing of newspapers, journals and periodicals", Category.CLASS),
        Classification("2213", "Publishing of music", Category.CLASS),
        Classification("2219", "Other publishing", Category.CLASS),
        Classification("222", "Printing and service activities related to printing", Category.GROUP),
        Classification("2221", "Printing", Category.CLASS),
        Classification("2222", "Service activities related to printing", Category.CLASS),
        Classification("223", "Reproduction of recorded media", Category.GROUP),
        Classification("2230", "Reproduction of recorded media", Category.CLASS),
        Classification("23", "Manufacture of coke, refined petroleum products and nuclear fuel", Category.DIVISION),
        Classification("231", "Manufacture of coke oven products", Category.GROUP),
        Classification("2310", "Manufacture of coke oven products", Category.CLASS),
        Classification("232", "Manufacture of refined petroleum products", Category.GROUP),
        Classification("2320", "Manufacture of refined petroleum products", Category.CLASS),
        Classification("233", "Processing of nuclear fuel", Category.GROUP),
        Classification("2330", "Processing of nuclear fuel", Category.CLASS),
        Classification("24", "Manufacture of chemicals and chemical products", Category.DIVISION),
        Classification("241", "Manufacture of basic chemicals", Category.GROUP),
        Classification(
            "2411", "Manufacture of basic chemicals, except fertilizers and nitrogen compounds", Category.CLASS
        ),
        Classification("2412", "Manufacture of fertilizers and nitrogen compounds", Category.CLASS),
        Classification("2413", "Manufacture of plastics in primary forms and of synthetic rubber", Category.CLASS),
        Classification("242", "Manufacture of other chemical products", Category.GROUP),
        Classification("2421", "Manufacture of pesticides and other agrochemical products", Category.CLASS),
        Classification(
            "2422", "Manufacture of paints, varnishes and similar coatings, printing ink and mastics", Category.CLASS
        ),
        Classification(
            "2423", "Manufacture of pharmaceuticals, medicinal chemicals and botanical products", Category.CLASS
        ),
        Classification(
            "2424",
            "Manufacture of soap and detergents, cleaning and polishing preparations, perfumes and toilet preparations",
            Category.CLASS,
        ),
        Classification("2429", "Manufacture of other chemical products n.e.c.", Category.CLASS),
        Classification("243", "Manufacture of man-made fibres", Category.GROUP),
        Classification("2430", "Manufacture of man-made fibres", Category.CLASS),
        Classification("25", "Manufacture of rubber and plastics products", Category.DIVISION),
        Classification("251", "Manufacture of rubber products", Category.GROUP),
        Classification(
            "2511", "Manufacture of rubber tyres and tubes; retreading and rebuilding of rubber tyres", Category.CLASS
        ),
        Classification("2519", "Manufacture of other rubber products", Category.CLASS),
        Classification("252", "Manufacture of plastics products", Category.GROUP),
        Classification("2520", "Manufacture of plastics products", Category.CLASS),
        Classification("26", "Manufacture of other non-metallic mineral products", Category.DIVISION),
        Classification("261", "Manufacture of glass and glass products", Category.GROUP),
        Classification("2610", "Manufacture of glass and glass products", Category.CLASS),
        Classification("269", "Manufacture of non-metallic mineral products n.e.c.", Category.GROUP),
        Classification("2691", "Manufacture of non-structural non-refractory ceramic ware", Category.CLASS),
        Classification("2692", "Manufacture of refractory ceramic products", Category.CLASS),
        Classification("2693", "Manufacture of structural non-refractory clay and ceramic products", Category.CLASS),
        Classification("2694", "Manufacture of cement, lime and plaster", Category.CLASS),
        Classification("2695", "Manufacture of articles of concrete, cement and plaster", Category.CLASS),
        Classification("2696", "Cutting, shaping and finishing of stone", Category.CLASS),
        Classification("2699", "Manufacture of other non-metallic mineral products n.e.c.", Category.CLASS),
        Classification("27", "Manufacture of basic metals", Category.DIVISION),
        Classification("271", "Manufacture of basic iron and steel", Category.GROUP),
        Classification("2710", "Manufacture of basic iron and steel", Category.CLASS),
        Classification("272", "Manufacture of basic precious and non-ferrous metals", Category.GROUP),
        Classification("2720", "Manufacture of basic precious and non-ferrous metals", Category.CLASS),
        Classification("273", "Casting of metals", Category.GROUP),
        Classification("2731", "Casting of iron and steel", Category.CLASS),
        Classification("2732", "Casting of non-ferrous metals", Category.CLASS),
        Classification(
            "28", "Manufacture of fabricated metal products, except machinery and equipment", Category.DIVISION
        ),
        Classification(
            "281", "Manufacture of structural metal products, tanks, reservoirs and steam generators", Category.GROUP
        ),
        Classification("2811", "Manufacture of structural metal products", Category.CLASS),
        Classification("2812", "Manufacture of tanks, reservoirs and containers of metal", Category.CLASS),
        Classification(
            "2813", "Manufacture of steam generators, except central heating hot water boilers", Category.CLASS
        ),
        Classification(
            "289", "Manufacture of other fabricated metal products; metalworking service activities", Category.GROUP
        ),
        Classification(
            "2891", "Forging, pressing, stamping and roll-forming of metal; powder metallurgy", Category.CLASS
        ),
        Classification(
            "2892",
            "Treatment and coating of metals; general mechanical engineering on a fee or contract basis",
            Category.CLASS,
        ),
        Classification("2893", "Manufacture of cutlery, hand tools and general hardware", Category.CLASS),
        Classification("2899", "Manufacture of other fabricated metal products n.e.c.", Category.CLASS),
        Classification("29", "Manufacture of machinery and equipment n.e.c.", Category.DIVISION),
        Classification("291", "Manufacture of general-purpose machinery", Category.GROUP),
        Classification(
            "2911", "Manufacture of engines and turbines, except aircraft, vehicle and cycle engines", Category.CLASS
        ),
        Classification("2912", "Manufacture of pumps, compressors, taps and valves", Category.CLASS),
        Classification("2913", "Manufacture of bearings, gears, gearing and driving elements", Category.CLASS),
        Classification("2914", "Manufacture of ovens, furnaces and furnace burners", Category.CLASS),
        Classification("2915", "Manufacture of lifting and handling equipment", Category.CLASS),
        Classification("2919", "Manufacture of other general-purpose machinery", Category.CLASS),
        Classification("292", "Manufacture of special-purpose machinery", Category.GROUP),
        Classification("2921", "Manufacture of agricultural and forestry machinery", Category.CLASS),
        Classification("2922", "Manufacture of machine tools", Category.CLASS),
        Classification("2923", "Manufacture of machinery for metallurgy", Category.CLASS),
        Classification("2924", "Manufacture of machinery for mining, quarrying and construction", Category.CLASS),
        Classification("2925", "Manufacture of machinery for food, beverage and tobacco processing", Category.CLASS),
        Classification("2926", "Manufacture of machinery for textile, apparel and leather production", Category.CLASS),
        Classification("2927", "Manufacture of weapons and ammunition", Category.CLASS),
        Classification("2929", "Manufacture of other special-purpose machinery", Category.CLASS),
        Classification("293", "Manufacture of domestic appliances n.e.c.", Category.GROUP),
        Classification("2930", "Manufacture of domestic appliances n.e.c.", Category.CLASS),
        Classification("30", "Manufacture of office, accounting and computing machinery", Category.DIVISION),
        Classification("300", "Manufacture of office, accounting and computing machinery", Category.GROUP),
        Classification("3000", "Manufacture of office, accounting and computing machinery", Category.CLASS),
        Classification("31", "Manufacture of electrical machinery and apparatus n.e.c.", Category.DIVISION),
        Classification("311", "Manufacture of electric motors, generators and transformers", Category.GROUP),
        Classification("3110", "Manufacture of electric motors, generators and transformers", Category.CLASS),
        Classification("312", "Manufacture of electricity distribution and control apparatus", Category.GROUP),
        Classification("3120", "Manufacture of electricity distribution and control apparatus", Category.CLASS),
        Classification("313", "Manufacture of insulated wire and cable", Category.GROUP),
        Classification("3130", "Manufacture of insulated wire and cable", Category.CLASS),
        Classification("314", "Manufacture of accumulators, primary cells and primary batteries", Category.GROUP),
        Classification("3140", "Manufacture of accumulators, primary cells and primary batteries", Category.CLASS),
        Classification("315", "Manufacture of electric lamps and lighting equipment", Category.GROUP),
        Classification("3150", "Manufacture of electric lamps and lighting equipment", Category.CLASS),
        Classification("319", "Manufacture of other electrical equipment n.e.c.", Category.GROUP),
        Classification("3190", "Manufacture of other electrical equipment n.e.c.", Category.CLASS),
        Classification(
            "32", "Manufacture of radio, television and communication equipment and apparatus", Category.DIVISION
        ),
        Classification(
            "321", "Manufacture of electronic valves and tubes and other electronic components", Category.GROUP
        ),
        Classification(
            "3210", "Manufacture of electronic valves and tubes and other electronic components", Category.CLASS
        ),
        Classification(
            "322",
            "Manufacture of television and radio transmitters and apparatus for line telephony and line telegraphy",
            Category.GROUP,
        ),
        Classification(
            "3220",
            "Manufacture of television and radio transmitters and apparatus for line telephony and line telegraphy",
            Category.CLASS,
        ),
        Classification(
            "323",
            "Manufacture of television and radio receivers, sound or video recording or reproducing apparatus, and associated goods",
            Category.GROUP,
        ),
        Classification(
            "3230",
            "Manufacture of television and radio receivers, sound or video recording or reproducing apparatus, and associated goods",
            Category.CLASS,
        ),
        Classification(
            "33", "Manufacture of medical, precision and optical instruments, watches and clocks", Category.DIVISION
        ),
        Classification(
            "331",
            "Manufacture of medical appliances and instruments and appliances for measuring, checking, testing, navigating and other purposes, except optical instruments",
            Category.GROUP,
        ),
        Classification(
            "3311", "Manufacture of medical and surgical equipment and orthopaedic appliances", Category.CLASS
        ),
        Classification(
            "3312",
            "Manufacture of instruments and appliances for measuring, checking, testing, navigating and other purposes, except industrial process control equipment",
            Category.CLASS,
        ),
        Classification("3313", "Manufacture of industrial process control equipment", Category.CLASS),
        Classification("332", "Manufacture of optical instruments and photographic equipment", Category.GROUP),
        Classification("3320", "Manufacture of optical instruments and photographic equipment", Category.CLASS),
        Classification("333", "Manufacture of watches and clocks", Category.GROUP),
        Classification("3330", "Manufacture of watches and clocks", Category.CLASS),
        Classification("34", "Manufacture of motor vehicles, trailers and semi-trailers", Category.DIVISION),
        Classification("341", "Manufacture of motor vehicles", Category.GROUP),
        Classification("3410", "Manufacture of motor vehicles", Category.CLASS),
        Classification(
            "342",
            "Manufacture of bodies (coachwork) for motor vehicles; manufacture of trailers and semi-trailers",
            Category.GROUP,
        ),
        Classification(
            "3420",
            "Manufacture of bodies (coachwork) for motor vehicles; manufacture of trailers and semi-trailers",
            Category.CLASS,
        ),
        Classification(
            "343", "Manufacture of parts and accessories for motor vehicles and their engines", Category.GROUP
        ),
        Classification(
            "3430", "Manufacture of parts and accessories for motor vehicles and their engines", Category.CLASS
        ),
        Classification("35", "Manufacture of other transport equipment", Category.DIVISION),
        Classification("351", "Building and repairing of ships and boats", Category.GROUP),
        Classification("3511", "Building and repairing of ships", Category.CLASS),
        Classification("3512", "Building and repairing of pleasure and sporting boats", Category.CLASS),
        Classification("352", "Manufacture of railway and tramway locomotives and rolling stock", Category.GROUP),
        Classification("3520", "Manufacture of railway and tramway locomotives and rolling stock", Category.CLASS),
        Classification("353", "Manufacture of aircraft and spacecraft", Category.GROUP),
        Classification("3530", "Manufacture of aircraft and spacecraft", Category.CLASS),
        Classification("359", "Manufacture of transport equipment n.e.c.", Category.GROUP),
        Classification("3591", "Manufacture of motorcycles", Category.CLASS),
        Classification("3592", "Manufacture of bicycles and invalid carriages", Category.CLASS),
        Classification("3599", "Manufacture of other transport equipment n.e.c.", Category.CLASS),
        Classification("36", "Manufacture of furniture; manufacturing n.e.c.", Category.DIVISION),
        Classification("361", "Manufacture of furniture", Category.GROUP),
        Classification("3610", "Manufacture of furniture", Category.CLASS),
        Classification("369", "Manufacturing n.e.c.", Category.GROUP),
        Classification("3691", "Manufacture of jewellery and related articles", Category.CLASS),
        Classification("3692", "Manufacture of musical instruments", Category.CLASS),
        Classification("3693", "Manufacture of sports goods", Category.CLASS),
        Classification("3694", "Manufacture of games and toys", Category.CLASS),
        Classification("3699", "Other manufacturing n.e.c.", Category.CLASS),
        Classification("37", "Recycling", Category.DIVISION),
        Classification("371", "Recycling of metal waste and scrap", Category.GROUP),
        Classification("3710", "Recycling of metal waste and scrap", Category.CLASS),
        Classification("372", "Recycling of non-metal waste and scrap", Category.GROUP),
        Classification("3720", "Recycling of non-metal waste and scrap", Category.CLASS),
        Classification("E", "Electricity, gas and water supply", Category.SECTION),
        Classification("40", "Electricity, gas, steam and hot water supply", Category.DIVISION),
        Classification("401", "Production, transmission and distribution of electricity", Category.GROUP),
        Classification("4010", "Production, transmission and distribution of electricity", Category.CLASS),
        Classification("402", "Manufacture of gas; distribution of gaseous fuels through mains", Category.GROUP),
        Classification("4020", "Manufacture of gas; distribution of gaseous fuels through mains", Category.CLASS),
        Classification("403", "Steam and hot water supply", Category.GROUP),
        Classification("4030", "Steam and hot water supply", Category.CLASS),
        Classification("41", "Collection, purification and distribution of water", Category.DIVISION),
        Classification("410", "Collection, purification and distribution of water", Category.GROUP),
        Classification("4100", "Collection, purification and distribution of water", Category.CLASS),
        Classification("F", "Construction", Category.SECTION),
        Classification("45", "Construction", Category.DIVISION),
        Classification("451", "Site preparation", Category.GROUP),
        Classification("4510", "Site preparation", Category.CLASS),
        Classification("452", "Building of complete constructions or parts thereof; civil engineering", Category.GROUP),
        Classification(
            "4520", "Building of complete constructions or parts thereof; civil engineering", Category.CLASS
        ),
        Classification("453", "Building installation", Category.GROUP),
        Classification("4530", "Building installation", Category.CLASS),
        Classification("454", "Building completion", Category.GROUP),
        Classification("4540", "Building completion", Category.CLASS),
        Classification("455", "Renting of construction or demolition equipment with operator", Category.GROUP),
        Classification("4550", "Renting of construction or demolition equipment with operator", Category.CLASS),
        Classification(
            "G",
            "Wholesale and retail trade; repair of motor vehicles, motorcycles and personal and household goods",
            Category.SECTION,
        ),
        Classification(
            "50",
            "Sale, maintenance and repair of motor vehicles and motorcycles; retail sale of automotive fuel",
            Category.DIVISION,
        ),
        Classification("501", "Sale of motor vehicles", Category.GROUP),
        Classification("5010", "Sale of motor vehicles", Category.CLASS),
        Classification("502", "Maintenance and repair of motor vehicles", Category.GROUP),
        Classification("5020", "Maintenance and repair of motor vehicles", Category.CLASS),
        Classification("503", "Sale of motor vehicle parts and accessories", Category.GROUP),
        Classification("5030", "Sale of motor vehicle parts and accessories", Category.CLASS),
        Classification(
            "504", "Sale, maintenance and repair of motorcycles and related parts and accessories", Category.GROUP
        ),
        Classification(
            "5040", "Sale, maintenance and repair of motorcycles and related parts and accessories", Category.CLASS
        ),
        Classification("505", "Retail sale of automotive fuel", Category.GROUP),
        Classification("5050", "Retail sale of automotive fuel", Category.CLASS),
        Classification(
            "51", "Wholesale trade and commission trade, except of motor vehicles and motorcycles", Category.DIVISION
        ),
        Classification("511", "Wholesale on a fee or contract basis", Category.GROUP),
        Classification("5110", "Wholesale on a fee or contract basis", Category.CLASS),
        Classification(
            "512", "Wholesale of agricultural raw materials, live animals, food, beverages and tobacco", Category.GROUP
        ),
        Classification("5121", "Wholesale of agricultural raw materials and live animals", Category.CLASS),
        Classification("5122", "Wholesale of food, beverages and tobacco", Category.CLASS),
        Classification("513", "Wholesale of household goods", Category.GROUP),
        Classification("5131", "Wholesale of textiles, clothing and footwear", Category.CLASS),
        Classification("5139", "Wholesale of other household goods", Category.CLASS),
        Classification("514", "Wholesale of non-agricultural intermediate products, waste and scrap", Category.GROUP),
        Classification("5141", "Wholesale of solid, liquid and gaseous fuels and related products", Category.CLASS),
        Classification("5142", "Wholesale of metals and metal ores", Category.CLASS),
        Classification(
            "5143",
            "Wholesale of construction materials, hardware, plumbing and heating equipment and supplies",
            Category.CLASS,
        ),
        Classification("5149", "Wholesale of other intermediate products, waste and scrap", Category.CLASS),
        Classification("515", "Wholesale of machinery, equipment and supplies", Category.GROUP),
        Classification("5151", "Wholesale of computers, computer peripheral equipment and software", Category.CLASS),
        Classification("5152", "Wholesale of electronic and telecommunications parts and equipment", Category.CLASS),
        Classification("5159", "Wholesale of other machinery, equipment and supplies", Category.CLASS),
        Classification("519", "Other wholesale", Category.GROUP),
        Classification("5190", "Other wholesale", Category.CLASS),
        Classification(
            "52",
            "Retail trade, except of motor vehicles and motorcycles; repair of personal and household goods",
            Category.DIVISION,
        ),
        Classification("521", "Non-specialized retail trade in stores", Category.GROUP),
        Classification(
            "5211",
            "Retail sale in non-specialized stores with food, beverages or tobacco predominating",
            Category.CLASS,
        ),
        Classification("5219", "Other retail sale in non-specialized stores", Category.CLASS),
        Classification("522", "Retail sale of food, beverages and tobacco in specialized stores", Category.GROUP),
        Classification("5220", "Retail sale of food, beverages and tobacco in specialized stores", Category.CLASS),
        Classification("523", "Other retail trade of new goods in specialized stores", Category.GROUP),
        Classification(
            "5231", "Retail sale of pharmaceutical and medical goods, cosmetic and toilet articles", Category.CLASS
        ),
        Classification("5232", "Retail sale of textiles, clothing, footwear and leather goods", Category.CLASS),
        Classification("5233", "Retail sale of household appliances, articles and equipment", Category.CLASS),
        Classification("5234", "Retail sale of hardware, paints and glass", Category.CLASS),
        Classification("5239", "Other retail sale in specialized stores", Category.CLASS),
        Classification("524", "Retail sale of second-hand goods in stores", Category.GROUP),
        Classification("5240", "Retail sale of second-hand goods in stores", Category.CLASS),
        Classification("525", "Retail trade not in stores", Category.GROUP),
        Classification("5251", "Retail sale via mail order houses", Category.CLASS),
        Classification("5252", "Retail sale via stalls and markets", Category.CLASS),
        Classification("5259", "Other non-store retail sale", Category.CLASS),
        Classification("526", "Repair of personal and household goods", Category.GROUP),
        Classification("5260", "Repair of personal and household goods", Category.CLASS),
        Classification("H", "Hotels and restaurants", Category.SECTION),
        Classification("55", "Hotels and restaurants", Category.DIVISION),
        Classification("551", "Hotels; camping sites and other provision of short-stay accommodation", Category.GROUP),
        Classification("5510", "Hotels; camping sites and other provision of short-stay accommodation", Category.CLASS),
        Classification("552", "Restaurants, bars and canteens", Category.GROUP),
        Classification("5520", "Restaurants, bars and canteens", Category.CLASS),
        Classification("I", "Transport, storage and communications", Category.SECTION),
        Classification("60", "Land transport; transport via pipelines", Category.DIVISION),
        Classification("601", "Transport via railways", Category.GROUP),
        Classification("6010", "Transport via railways", Category.CLASS),
        Classification("602", "Other land transport", Category.GROUP),
        Classification("6021", "Other scheduled passenger land transport", Category.CLASS),
        Classification("6022", "Other non-scheduled passenger land transport", Category.CLASS),
        Classification("6023", "Freight transport by road", Category.CLASS),
        Classification("603", "Transport via pipelines", Category.GROUP),
        Classification("6030", "Transport via pipelines", Category.CLASS),
        Classification("61", "Water transport", Category.DIVISION),
        Classification("611", "Sea and coastal water transport", Category.GROUP),
        Classification("6110", "Sea and coastal water transport", Category.CLASS),
        Classification("612", "Inland water transport", Category.GROUP),
        Classification("6120", "Inland water transport", Category.CLASS),
        Classification("62", "Air transport", Category.DIVISION),
        Classification("621", "Scheduled air transport", Category.GROUP),
        Classification("6210", "Scheduled air transport", Category.CLASS),
        Classification("622", "Non-scheduled air transport", Category.GROUP),
        Classification("6220", "Non-scheduled air transport", Category.CLASS),
        Classification(
            "63", "Supporting and auxiliary transport activities; activities of travel agencies", Category.DIVISION
        ),
        Classification(
            "630", "Supporting and auxiliary transport activities; activities of travel agencies", Category.GROUP
        ),
        Classification("6301", "Cargo handling", Category.CLASS),
        Classification("6302", "Storage and warehousing", Category.CLASS),
        Classification("6303", "Other supporting transport activities", Category.CLASS),
        Classification(
            "6304",
            "Activities of travel agencies and tour operators; tourist assistance activities n.e.c.",
            Category.CLASS,
        ),
        Classification("6309", "Activities of other transport agencies", Category.CLASS),
        Classification("64", "Post and telecommunications", Category.DIVISION),
        Classification("641", "Post and courier activities", Category.GROUP),
        Classification("6411", "National post activities", Category.CLASS),
        Classification("6412", "Courier activities other than national post activities", Category.CLASS),
        Classification("642", "Telecommunications", Category.GROUP),
        Classification("6420", "Telecommunications", Category.CLASS),
        Classification("J", "Financial intermediation", Category.SECTION),
        Classification("65", "Financial intermediation, except insurance and pension funding", Category.DIVISION),
        Classification("651", "Monetary intermediation", Category.GROUP),
        Classification("6511", "Central banking", Category.CLASS),
        Classification("6519", "Other monetary intermediation", Category.CLASS),
        Classification("659", "Other financial intermediation", Category.GROUP),
        Classification("6591", "Financial leasing", Category.CLASS),
        Classification("6592", "Other credit granting", Category.CLASS),
        Classification("6599", "Other financial intermediation n.e.c.", Category.CLASS),
        Classification("66", "Insurance and pension funding, except compulsory social security", Category.DIVISION),
        Classification("660", "Insurance and pension funding, except compulsory social security", Category.GROUP),
        Classification("6601", "Life insurance", Category.CLASS),
        Classification("6602", "Pension funding", Category.CLASS),
        Classification("6603", "Non-life insurance", Category.CLASS),
        Classification("67", "Activities auxiliary to financial intermediation", Category.DIVISION),
        Classification(
            "671",
            "Activities auxiliary to financial intermediation, except insurance and pension funding",
            Category.GROUP,
        ),
        Classification("6711", "Administration of financial markets", Category.CLASS),
        Classification("6712", "Security dealing activities", Category.CLASS),
        Classification("6719", "Activities auxiliary to financial intermediation n.e.c.", Category.CLASS),
        Classification("672", "Activities auxiliary to insurance and pension funding", Category.GROUP),
        Classification("6720", "Activities auxiliary to insurance and pension funding", Category.CLASS),
        Classification("K", "Real estate, renting and business activities", Category.SECTION),
        Classification("70", "Real estate activities", Category.DIVISION),
        Classification("701", "Real estate activities with own or leased property", Category.GROUP),
        Classification("7010", "Real estate activities with own or leased property", Category.CLASS),
        Classification("702", "Real estate activities on a fee or contract basis", Category.GROUP),
        Classification("7020", "Real estate activities on a fee or contract basis", Category.CLASS),
        Classification(
            "71",
            "Renting of machinery and equipment without operator and of personal and household goods",
            Category.DIVISION,
        ),
        Classification("711", "Renting of transport equipment", Category.GROUP),
        Classification("7111", "Renting of land transport equipment", Category.CLASS),
        Classification("7112", "Renting of water transport equipment", Category.CLASS),
        Classification("7113", "Renting of air transport equipment", Category.CLASS),
        Classification("712", "Renting of other machinery and equipment", Category.GROUP),
        Classification("7121", "Renting of agricultural machinery and equipment", Category.CLASS),
        Classification("7122", "Renting of construction and civil engineering machinery and equipment", Category.CLASS),
        Classification("7123", "Renting of office machinery and equipment (including computers)", Category.CLASS),
        Classification("7129", "Renting of other machinery and equipment n.e.c.", Category.CLASS),
        Classification("713", "Renting of personal and household goods n.e.c.", Category.GROUP),
        Classification("7130", "Renting of personal and household goods n.e.c.", Category.CLASS),
        Classification("72", "Computer and related activities", Category.DIVISION),
        Classification("721", "Hardware consultancy", Category.GROUP),
        Classification("7210", "Hardware consultancy", Category.CLASS),
        Classification("722", "Software publishing, consultancy and supply", Category.GROUP),
        Classification("7221", "Software publishing", Category.CLASS),
        Classification("7229", "Other software consultancy and supply", Category.CLASS),
        Classification("723", "Data processing", Category.GROUP),
        Classification("7230", "Data processing", Category.CLASS),
        Classification("724", "Database activities and online distribution of electronic content", Category.GROUP),
        Classification("7240", "Database activities and online distribution of electronic content", Category.CLASS),
        Classification("725", "Maintenance and repair of office, accounting and computing machinery", Category.GROUP),
        Classification("7250", "Maintenance and repair of office, accounting and computing machinery", Category.CLASS),
        Classification("729", "Other computer-related activities", Category.GROUP),
        Classification("7290", "Other computer-related activities", Category.CLASS),
        Classification("73", "Research and development", Category.DIVISION),
        Classification(
            "731", "Research and experimental development on natural sciences and engineering (NSE)", Category.GROUP
        ),
        Classification(
            "7310", "Research and experimental development on natural sciences and engineering (NSE)", Category.CLASS
        ),
        Classification(
            "732", "Research and experimental development on social sciences and humanities (SSH)", Category.GROUP
        ),
        Classification(
            "7320", "Research and experimental development on social sciences and humanities (SSH)", Category.CLASS
        ),
        Classification("74", "Other business activities", Category.DIVISION),
        Classification(
            "741",
            "Legal, accounting, bookkeeping and auditing activities; tax consultancy; market research and public opinion polling; business and management consultancy",
            Category.GROUP,
        ),
        Classification("7411", "Legal activities", Category.CLASS),
        Classification("7412", "Accounting, bookkeeping and auditing activities; tax consultancy", Category.CLASS),
        Classification("7413", "Market research and public opinion polling", Category.CLASS),
        Classification("7414", "Business and management consultancy activities", Category.CLASS),
        Classification("742", "Architectural, engineering and other technical activities", Category.GROUP),
        Classification(
            "7421", "Architectural and engineering activities and related technical consultancy", Category.CLASS
        ),
        Classification("7422", "Technical testing and analysis", Category.CLASS),
        Classification("743", "Advertising", Category.GROUP),
        Classification("7430", "Advertising", Category.CLASS),
        Classification("749", "Business activities n.e.c.", Category.GROUP),
        Classification("7491", "Labour recruitment and provision of personnel", Category.CLASS),
        Classification("7492", "Investigation and security activities", Category.CLASS),
        Classification("7493", "Building-cleaning and industrial-cleaning activities", Category.CLASS),
        Classification("7494", "Photographic activities", Category.CLASS),
        Classification("7495", "Packaging activities", Category.CLASS),
        Classification("7499", "Other business activities n.e.c.", Category.CLASS),
        Classification("L", "Public administration and defence; compulsory social security", Category.SECTION),
        Classification("75", "Public administration and defence; compulsory social security", Category.DIVISION),
        Classification(
            "751", "Administration of the State and the economic and social policy of the community", Category.GROUP
        ),
        Classification("7511", "General (overall) public service activities", Category.CLASS),
        Classification(
            "7512",
            "Regulation of the activities of agencies that provide health care, education, cultural services and other social services, excluding social security",
            Category.CLASS,
        ),
        Classification(
            "7513", "Regulation of and contribution to more efficient operation of business", Category.CLASS
        ),
        Classification("7514", "Supporting service activities for the government as a whole", Category.CLASS),
        Classification("752", "Provision of services to the community as a whole", Category.GROUP),
        Classification("7521", "Foreign affairs", Category.CLASS),
        Classification("7522", "Defence activities", Category.CLASS),
        Classification("7523", "Public order and safety activities", Category.CLASS),
        Classification("753", "Compulsory social security activities", Category.GROUP),
        Classification("7530", "Compulsory social security activities", Category.CLASS),
        Classification("M", "Education", Category.SECTION),
        Classification("80", "Education", Category.DIVISION),
        Classification("801", "Primary education", Category.GROUP),
        Classification("8010", "Primary education", Category.CLASS),
        Classification("802", "Secondary education", Category.GROUP),
        Classification("8021", "General secondary education", Category.CLASS),
        Classification("8022", "Technical and vocational secondary education", Category.CLASS),
        Classification("803", "Higher education", Category.GROUP),
        Classification("8030", "Higher education", Category.CLASS),
        Classification("809", "Other education", Category.GROUP),
        Classification("8090", "Other education", Category.CLASS),
        Classification("N", "Health and social work", Category.SECTION),
        Classification("85", "Health and social work", Category.DIVISION),
        Classification("851", "Human health activities", Category.GROUP),
        Classification("8511", "Hospital activities", Category.CLASS),
        Classification("8512", "Medical and dental practice activities", Category.CLASS),
        Classification("8519", "Other human health activities", Category.CLASS),
        Classification("852", "Veterinary activities", Category.GROUP),
        Classification("8520", "Veterinary activities", Category.CLASS),
        Classification("853", "Social work activities", Category.GROUP),
        Classification("8531", "Social work activities with accommodation", Category.CLASS),
        Classification("8532", "Social work activities without accommodation", Category.CLASS),
        Classification("O", "Other community, social and personal service activities", Category.SECTION),
        Classification("90", "Sewage and refuse disposal, sanitation and similar activities", Category.DIVISION),
        Classification("900", "Sewage and refuse disposal, sanitation and similar activities", Category.GROUP),
        Classification("9000", "Sewage and refuse disposal, sanitation and similar activities", Category.CLASS),
        Classification("91", "Activities of membership organizations n.e.c.", Category.DIVISION),
        Classification("911", "Activities of business, employers and professional organizations", Category.GROUP),
        Classification("9111", "Activities of business and employers organizations", Category.CLASS),
        Classification("9112", "Activities of professional organizations", Category.CLASS),
        Classification("912", "Activities of trade unions", Category.GROUP),
        Classification("9120", "Activities of trade unions", Category.CLASS),
        Classification("919", "Activities of other membership organizations", Category.GROUP),
        Classification("9191", "Activities of religious organizations", Category.CLASS),
        Classification("9192", "Activities of political organizations", Category.CLASS),
        Classification("9199", "Activities of other membership organizations n.e.c.", Category.CLASS),
        Classification("92", "Recreational, cultural and sporting activities", Category.DIVISION),
        Classification("921", "Motion picture, radio, television and other entertainment activities", Category.GROUP),
        Classification("9211", "Motion picture and video production and distribution", Category.CLASS),
        Classification("9212", "Motion picture projection", Category.CLASS),
        Classification("9213", "Radio and television activities", Category.CLASS),
        Classification("9214", "Dramatic arts, music and other arts activities", Category.CLASS),
        Classification("9219", "Other entertainment activities n.e.c.", Category.CLASS),
        Classification("922", "News agency activities", Category.GROUP),
        Classification("9220", "News agency activities", Category.CLASS),
        Classification("923", "Library, archives, museums and other cultural activities", Category.GROUP),
        Classification("9231", "Library and archives activities", Category.CLASS),
        Classification("9232", "Museums activities and preservation of historic sites and buildings", Category.CLASS),
        Classification("9233", "Botanical and zoological gardens and nature reserves activities", Category.CLASS),
        Classification("924", "Sporting and other recreational activities", Category.GROUP),
        Classification("9241", "Sporting activities", Category.CLASS),
        Classification("9249", "Other recreational activities", Category.CLASS),
        Classification("93", "Other service activities", Category.DIVISION),
        Classification("930", "Other service activities", Category.GROUP),
        Classification("9301", "Washing and (dry-)cleaning of textile and fur products", Category.CLASS),
        Classification("9302", "Hairdressing and other beauty treatment", Category.CLASS),
        Classification("9303", "Funeral and related activities", Category.CLASS),
        Classification("9309", "Other service activities n.e.c.", Category.CLASS),
        Classification(
            "P",
            "Activities of private households as employers and undifferentiated production activities of private households",
            Category.SECTION,
        ),
        Classification("95", "Activities of private households as employers of domestic staff", Category.DIVISION),
        Classification("950", "Activities of private households as employers of domestic staff", Category.GROUP),
        Classification("9500", "Activities of private households as employers of domestic staff", Category.CLASS),
        Classification(
            "96", "Undifferentiated goods-producing activities of private households for own use", Category.DIVISION
        ),
        Classification(
            "960", "Undifferentiated goods-producing activities of private households for own use", Category.GROUP
        ),
        Classification(
            "9600", "Undifferentiated goods-producing activities of private households for own use", Category.CLASS
        ),
        Classification(
            "97", "Undifferentiated service-producing activities of private households for own use", Category.DIVISION
        ),
        Classification(
            "970", "Undifferentiated service-producing activities of private households for own use", Category.GROUP
        ),
        Classification(
            "9700", "Undifferentiated service-producing activities of private households for own use", Category.CLASS
        ),
        Classification("Q", "Extraterritorial organizations and bodies", Category.SECTION),
        Classification("99", "Extraterritorial organizations and bodies", Category.DIVISION),
        Classification("990", "Extraterritorial organizations and bodies", Category.GROUP),
        Classification("9900", "Extraterritorial organizations and bodies", Category.CLASS),
    ],
)



# -*- coding: utf-8 -*-
"""`SKD 2002 - Standard Classification of Activities 2002 <https://www.stat.si/statweb/en/methods/classifications>`_.
"""
from ...types import Category, Classification, Standard, Standards

SKD2002 = Standard(
    standard=Standards.SKD2002,
    classes=[
        Classification("01.110", "Pridelovanje žit in drugih poljščin", Category.CLASS),
        Classification("01.120", "Pridelovanje vrtnin, okrasnih rastlin, semen in sadik", Category.CLASS),
        Classification("01.131", "Vinogradništvo", Category.CLASS),
        Classification("01.132", "Sadjarstvo", Category.CLASS),
        Classification("01.210", "Reja govedi", Category.CLASS),
        Classification("01.220", "Reja ovac, koz, konj, oslov, mul in mezgov", Category.CLASS),
        Classification("01.230", "Reja prašičev", Category.CLASS),
        Classification("01.240", "Reja perutnine", Category.CLASS),
        Classification("01.250", "Reja drugih živali", Category.CLASS),
        Classification("01.300", "Mešano kmetijstvo", Category.CLASS),
        Classification("01.411", "Urejanje in vzdrževanje parkov, vrtov in zelenih športnih površin", Category.CLASS),
        Classification("01.412", "Druge storitve za rastlinsko pridelavo", Category.CLASS),
        Classification("01.420", "Storitve za živinorejo, razen veterinarskih storitev", Category.CLASS),
        Classification("01.500", "Lov in lovske storitve", Category.CLASS),
        Classification("02.010", "Gozdarstvo", Category.CLASS),
        Classification("02.020", "Gozdarske storitve", Category.CLASS),
        Classification("05.010", "Ribolov", Category.CLASS),
        Classification("05.020", "Ribogojstvo", Category.CLASS),
        Classification("10.100", "Pridobivanje črnega premoga", Category.CLASS),
        Classification("10.200", "Pridobivanje rjavega premoga in lignita", Category.CLASS),
        Classification("10.300", "Pridobivanje šote", Category.CLASS),
        Classification("11.100", "Pridobivanje surove nafte in zemeljskega plina", Category.CLASS),
        Classification(
            "11.200",
            "Storitve v zvezi s pridobivanjem surove nafte in zemeljskega plina, brez iskanja nahajališč",
            Category.CLASS,
        ),
        Classification("12.000", "Pridobivanje uranovih in torijevih rud", Category.CLASS),
        Classification("13.100", "Pridobivanje železove rude", Category.CLASS),
        Classification("13.200", "Pridobivanje rud neželeznih kovin, razen uranove in torijeve rude", Category.CLASS),
        Classification("14.110", "Pridobivanje okrasnega in gradbenega kamna", Category.CLASS),
        Classification("14.120", "Pridobivanje apnenca, sadre in krede", Category.CLASS),
        Classification("14.130", "Pridobivanje skrilavcev", Category.CLASS),
        Classification("14.210", "Pridobivanje gramoza in peska", Category.CLASS),
        Classification("14.220", "Pridobivanje gline in kaolina", Category.CLASS),
        Classification(
            "14.300", "Pridobivanje mineralov za kemijsko proizvodnjo in proizvodnjo mineralnih gnojil", Category.CLASS
        ),
        Classification("14.400", "Pridobivanje soli", Category.CLASS),
        Classification("14.500", "Pridobivanje drugih rudnin in kamnin", Category.CLASS),
        Classification("15.110", "Proizvodnja in konzerviranje mesa, razen perutninskega", Category.CLASS),
        Classification("15.120", "Proizvodnja in konzerviranje perutninskega mesa", Category.CLASS),
        Classification("15.130", "Proizvodnja mesnih izdelkov, tudi iz perutninskega mesa", Category.CLASS),
        Classification("15.200", "Predelava in konzerviranje rib, proizvodnja ribjih izdelkov", Category.CLASS),
        Classification("15.310", "Predelava in konzerviranje krompirja", Category.CLASS),
        Classification("15.320", "Proizvodnja sadnih in zelenjavnih sokov", Category.CLASS),
        Classification("15.330", "Druga predelava in konzerviranje sadja in zelenjave", Category.CLASS),
        Classification("15.410", "Proizvodnja surovega olja in maščob", Category.CLASS),
        Classification("15.420", "Proizvodnja rafiniranega olja in maščob", Category.CLASS),
        Classification("15.430", "Proizvodnja margarine in podobnih jedilnih maščob", Category.CLASS),
        Classification("15.510", "Mlekarstvo in sirarstvo, proizvodnja mlečnih izdelkov", Category.CLASS),
        Classification("15.520", "Proizvodnja sladoleda", Category.CLASS),
        Classification("15.610", "Mlinarstvo", Category.CLASS),
        Classification("15.620", "Proizvodnja škroba in škrobnih izdelkov", Category.CLASS),
        Classification("15.710", "Proizvodnja krmil", Category.CLASS),
        Classification("15.720", "Proizvodnja hrane za hišne živali", Category.CLASS),
        Classification("15.810", "Proizvodnja kruha, svežega peciva in slaščic", Category.CLASS),
        Classification(
            "15.820", "Proizvodnja prepečenca in piškotov; proizvodnja trajnega peciva in slaščic", Category.CLASS
        ),
        Classification("15.830", "Proizvodnja sladkorja", Category.CLASS),
        Classification("15.840", "Proizvodnja kakava, čokolade in sladkornih izdelkov", Category.CLASS),
        Classification("15.850", "Proizvodnja testenin", Category.CLASS),
        Classification("15.860", "Predelava čaja in kave", Category.CLASS),
        Classification("15.870", "Proizvodnja različnih začimb, dišav in drugih dodatkov", Category.CLASS),
        Classification("15.880", "Proizvodnja homogeniziranih živil in dietetične hrane", Category.CLASS),
        Classification("15.890", "Proizvodnja drugih živil, d. n.", Category.CLASS),
        Classification("15.910", "Proizvodnja žganih pijač", Category.CLASS),
        Classification("15.920", "Proizvodnja etilnega alkohola", Category.CLASS),
        Classification("15.930", "Proizvodnja vina iz grozdja", Category.CLASS),
        Classification("15.940", "Proizvodnja drugih fermentiranih pijač in sadnih vin", Category.CLASS),
        Classification("15.950", "Proizvodnja aromatiziranih vin iz svežega grozdja", Category.CLASS),
        Classification("15.960", "Proizvodnja piva", Category.CLASS),
        Classification("15.970", "Proizvodnja slada", Category.CLASS),
        Classification("15.980", "Proizvodnja mineralnih vod in brezalkoholnih pijač", Category.CLASS),
        Classification("16.000", "Proizvodnja tobačnih izdelkov", Category.CLASS),
        Classification("17.100", "Priprava in predenje tekstilnih vlaken", Category.CLASS),
        Classification("17.20", "Tkanje tekstilij", Category.CLASS),
        Classification("17.200", "Tkanje tekstilij", Category.CLASS),
        Classification("17.300", "Plemenitenje tekstilij", Category.CLASS),
        Classification("17.400", "Proizvodnja tekstilnih izdelkov, razen oblačil", Category.CLASS),
        Classification("17.510", "Proizvodnja preprog in talnih oblog", Category.CLASS),
        Classification("17.520", "Proizvodnja vrvi, vrvic in mrež", Category.CLASS),
        Classification("17.530", "Proizvodnja netkanih tekstilij in izdelkov iz njih, razen oblačil", Category.CLASS),
        Classification("17.540", "Proizvodnja drugih tekstilij, d. n.", Category.CLASS),
        Classification("17.600", "Proizvodnja pletenih in kvačkanih materialov", Category.CLASS),
        Classification("17.710", "Proizvodnja nogavic", Category.CLASS),
        Classification("17.720", "Proizvodnja pletenih in kvačkanih oblačil", Category.CLASS),
        Classification("18.100", "Proizvodnja usnjenih oblačil", Category.CLASS),
        Classification("18.210", "Proizvodnja delovnih oblačil", Category.CLASS),
        Classification("18.220", "Proizvodnja drugih vrhnjih oblačil", Category.CLASS),
        Classification("18.230", "Proizvodnja spodnjega perila", Category.CLASS),
        Classification("18.240", "Proizvodnja športnih in drugih oblačil, pokrival ter dodatkov", Category.CLASS),
        Classification("18.300", "Strojenje in dodelava krzna; proizvodnja krznenih izdelkov", Category.CLASS),
        Classification("19.100", "Strojenje in dodelava usnja", Category.CLASS),
        Classification(
            "19.200", "Proizvodnja potovalne galanterije, sedlarskih in jermenarskih izdelkov", Category.CLASS
        ),
        Classification("19.300", "Proizvodnja obutve", Category.CLASS),
        Classification("20.100", "Žaganje in skobljanje lesa ter impregniranje lesa", Category.CLASS),
        Classification(
            "20.200",
            "Proizvodnja furnirja, vezanega in slojastega lesa, ivernih, vlaknenih in drugih plošč",
            Category.CLASS,
        ),
        Classification("20.300", "Stavbno mizarstvo", Category.CLASS),
        Classification("20.400", "Proizvodnja lesene embalaže", Category.CLASS),
        Classification("20.510", "Proizvodnja drugih izdelkov iz lesa", Category.CLASS),
        Classification("20.520", "Proizvodnja izdelkov iz plute, slame in protja", Category.CLASS),
        Classification("21.110", "Proizvodnja vlaknin", Category.CLASS),
        Classification("21.120", "Proizvodnja papirja in kartona", Category.CLASS),
        Classification(
            "21.210", "Proizvodnja valovitega papirja in kartona ter papirne in kartonske embalaže", Category.CLASS
        ),
        Classification(
            "21.220", "Proizvodnja gospodinjskih, higienskih in toaletnih potrebščin iz papirja", Category.CLASS
        ),
        Classification("21.230", "Proizvodnja pisarniških potrebščin iz papirja", Category.CLASS),
        Classification("21.240", "Proizvodnja tapet", Category.CLASS),
        Classification("21.250", "Proizvodnja drugih izdelkov iz papirja in kartona", Category.CLASS),
        Classification("22.110", "Izdajanje knjig", Category.CLASS),
        Classification("22.120", "Izdajanje časopisov", Category.CLASS),
        Classification("22.130", "Izdajanje revij in periodike", Category.CLASS),
        Classification("22.140", "Izdajanje posnetih nosilcev zvočnega zapisa", Category.CLASS),
        Classification("22.150", "Drugo založništvo", Category.CLASS),
        Classification("22.210", "Tiskanje časopisov", Category.CLASS),
        Classification("22.220", "Drugo tiskarstvo", Category.CLASS),
        Classification("22.230", "Knjigoveštvo", Category.CLASS),
        Classification("22.240", "Priprava za tisk", Category.CLASS),
        Classification("22.250", "Druge dejavnosti, povezane s tiskarstvom", Category.CLASS),
        Classification("22.310", "Razmnoževanje zvočnih zapisov", Category.CLASS),
        Classification("22.320", "Razmnoževanje video zapisov", Category.CLASS),
        Classification("22.330", "Razmnoževanje računalniških zapisov", Category.CLASS),
        Classification("23.100", "Proizvodnja koksa", Category.CLASS),
        Classification("23.200", "Proizvodnja naftnih derivatov", Category.CLASS),
        Classification("23.300", "Proizvodnja jedrskega goriva", Category.CLASS),
        Classification("24.110", "Proizvodnja tehničnih plinov", Category.CLASS),
        Classification("24.120", "Proizvodnja barvil in pigmentov", Category.CLASS),
        Classification("24.130", "Proizvodnja drugih anorganskih osnovnih kemikalij", Category.CLASS),
        Classification("24.140", "Proizvodnja drugih organskih osnovnih kemikalij", Category.CLASS),
        Classification("24.150", "Proizvodnja gnojil in dušikovih spojin", Category.CLASS),
        Classification("24.160", "Proizvodnja plastičnih mas v primarni obliki", Category.CLASS),
        Classification("24.170", "Proizvodnja sintetičnega kavčuka v primarni obliki", Category.CLASS),
        Classification("24.200", "Proizvodnja razkužil, pesticidov in drugih agrokemičnih izdelkov", Category.CLASS),
        Classification(
            "24.300", "Proizvodnja kritnih barv, lakov in podobnih premazov, tiskarskih barv in kitov", Category.CLASS
        ),
        Classification("24.410", "Proizvodnja farmacevtskih surovin", Category.CLASS),
        Classification("24.420", "Proizvodnja farmacevtskih preparatov", Category.CLASS),
        Classification("24.510", "Proizvodnja mil in pralnih sredstev, čistilnih in polirnih sredstev", Category.CLASS),
        Classification("24.520", "Proizvodnja parfumov in toaletnih sredstev", Category.CLASS),
        Classification("24.610", "Proizvodnja razstreliv", Category.CLASS),
        Classification("24.620", "Proizvodnja sredstev za lepljenje", Category.CLASS),
        Classification("24.630", "Proizvodnja eteričnih olj", Category.CLASS),
        Classification("24.640", "Proizvodnja fotografskih kemikalij", Category.CLASS),
        Classification("24.650", "Proizvodnja neposnetih nosilcev zapisa", Category.CLASS),
        Classification("24.660", "Proizvodnja drugih kemičnih izdelkov", Category.CLASS),
        Classification("24.700", "Proizvodnja umetnih vlaken", Category.CLASS),
        Classification("25.110", "Proizvodnja plaščev in zračnic za vozila", Category.CLASS),
        Classification("25.120", "Obnavljanje in protektiranje gum za vozila", Category.CLASS),
        Classification("25.130", "Proizvodnja drugih izdelkov iz gume", Category.CLASS),
        Classification("25.210", "Proizvodnja plošč, folij, cevi in profilov iz plastičnih mas", Category.CLASS),
        Classification("25.220", "Proizvodnja embalaže iz plastičnih mas", Category.CLASS),
        Classification("25.230", "Proizvodnja izdelkov iz plastičnih mas za gradbeništvo", Category.CLASS),
        Classification("25.240", "Proizvodnja drugih izdelkov iz plastičnih mas", Category.CLASS),
        Classification("26.110", "Proizvodnja ravnega stekla", Category.CLASS),
        Classification("26.120", "Oblikovanje in obdelava ravnega stekla", Category.CLASS),
        Classification("26.130", "Proizvodnja votlega stekla", Category.CLASS),
        Classification("26.140", "Proizvodnja steklenih vlaken", Category.CLASS),
        Classification(
            "26.150", "Proizvodnja in oblikovanje drugih vrst stekla ter tehničnih steklenih izdelkov", Category.CLASS
        ),
        Classification("26.210", "Proizvodnja gospodinjske in okrasne keramike", Category.CLASS),
        Classification("26.220", "Proizvodnja sanitarne keramike", Category.CLASS),
        Classification("26.230", "Proizvodnja izolatorjev in izolacijskih elementov iz keramike", Category.CLASS),
        Classification("26.240", "Proizvodnja druge tehnične keramike", Category.CLASS),
        Classification("26.250", "Proizvodnja drugih keramičnih izdelkov", Category.CLASS),
        Classification("26.260", "Proizvodnja ognjevzdržne keramike", Category.CLASS),
        Classification("26.300", "Proizvodnja zidnih in talnih keramičnih ploščic", Category.CLASS),
        Classification(
            "26.400", "Proizvodnja strešnikov, opeke in drugih keramičnih materialov za gradbeništvo", Category.CLASS
        ),
        Classification("26.510", "Proizvodnja cementa", Category.CLASS),
        Classification("26.520", "Proizvodnja apna", Category.CLASS),
        Classification("26.530", "Proizvodnja mavca", Category.CLASS),
        Classification("26.610", "Proizvodnja betonskih izdelkov za gradbeništvo", Category.CLASS),
        Classification("26.620", "Proizvodnja izdelkov iz mavca za gradbeništvo", Category.CLASS),
        Classification("26.630", "Proizvodnja sveže betonske mešanice", Category.CLASS),
        Classification("26.640", "Proizvodnja malte", Category.CLASS),
        Classification("26.650", "Proizvodnja izdelkov iz vlaknatega cementa", Category.CLASS),
        Classification("26.660", "Proizvodnja drugih izdelkov iz betona, cementa, mavca", Category.CLASS),
        Classification("26.700", "Obdelava naravnega kamna", Category.CLASS),
        Classification("26.810", "Proizvodnja brusilnih sredstev", Category.CLASS),
        Classification("26.820", "Proizvodnja drugih nekovinskih mineralnih izdelkov", Category.CLASS),
        Classification("27.100", "Proizvodnja železa, jekla, ferozlitin", Category.CLASS),
        Classification("27.210", "Proizvodnja litoželeznih cevi", Category.CLASS),
        Classification("27.220", "Proizvodnja jeklenih cevi", Category.CLASS),
        Classification("27.310", "Hladno vlečenje", Category.CLASS),
        Classification("27.320", "Hladno valjanje ozkega traku", Category.CLASS),
        Classification("27.330", "Hladno profiliranje", Category.CLASS),
        Classification("27.340", "Vlečenje žice", Category.CLASS),
        Classification("27.410", "Proizvodnja plemenitih kovin", Category.CLASS),
        Classification("27.420", "Proizvodnja aluminija", Category.CLASS),
        Classification("27.430", "Proizvodnja svinca, cinka in kositra", Category.CLASS),
        Classification("27.440", "Proizvodnja bakra", Category.CLASS),
        Classification("27.450", "Proizvodnja drugih neželeznih kovin", Category.CLASS),
        Classification("27.510", "Litje železa", Category.CLASS),
        Classification("27.520", "Litje jekla", Category.CLASS),
        Classification("27.530", "Litje lahkih kovin", Category.CLASS),
        Classification("27.540", "Litje drugih neželeznih kovin", Category.CLASS),
        Classification("28.110", "Proizvodnja kovinskih konstrukcij in njihovih delov", Category.CLASS),
        Classification("28.120", "Proizvodnja kovinskega stavbnega pohištva", Category.CLASS),
        Classification("28.210", "Proizvodnja kovinskih rezervoarjev, cistern, kontejnerjev", Category.CLASS),
        Classification("28.220", "Proizvodnja radiatorjev in kotlov za centralno ogrevanje", Category.CLASS),
        Classification("28.300", "Proizvodnja parnih kotlov, razen kotlov za centralno ogrevanje", Category.CLASS),
        Classification(
            "28.400", "Kovanje, stiskanje, vtiskovanje in valjanje kovin; prašna metalurgija", Category.CLASS
        ),
        Classification("28.511", "Prekrivanje kovin s kovino", Category.CLASS),
        Classification("28.512", "Druga površinska in toplotna obdelava kovin", Category.CLASS),
        Classification("28.520", "Splošna mehanična dela", Category.CLASS),
        Classification("28.610", "Proizvodnja rezilnega orodja", Category.CLASS),
        Classification("28.621", "Proizvodnja ročnega orodja", Category.CLASS),
        Classification("28.622", "Proizvodnja orodja za stroje", Category.CLASS),
        Classification("28.630", "Proizvodnja ključavnic, okovja", Category.CLASS),
        Classification("28.710", "Proizvodnja jeklenih bobnov, sodov in podobnih posod", Category.CLASS),
        Classification("28.720", "Proizvodnja lahke kovinske embalaže", Category.CLASS),
        Classification("28.730", "Proizvodnja izdelkov iz žice", Category.CLASS),
        Classification("28.740", "Proizvodnja vijačnega materiala, vezi, verig, vzmeti", Category.CLASS),
        Classification("28.750", "Proizvodnja drugih kovinskih izdelkov, d. n.", Category.CLASS),
        Classification("29.110", "Proizvodnja motorjev in turbin, razen za letala in motorna vozila", Category.CLASS),
        Classification("29.120", "Proizvodnja črpalk in kompresorjev", Category.CLASS),
        Classification("29.130", "Proizvodnja pip in ventilov", Category.CLASS),
        Classification(
            "29.140", "Proizvodnja ležajev, zobnikov in elementov za mehanski prenos energije", Category.CLASS
        ),
        Classification("29.210", "Proizvodnja peči in gorilnikov", Category.CLASS),
        Classification("29.220", "Proizvodnja dvigalnih in transportnih naprav", Category.CLASS),
        Classification(
            "29.230", "Proizvodnja hladilnih in prezračevalnih naprav, razen za gospodinjstva", Category.CLASS
        ),
        Classification("29.240", "Proizvodnja drugih naprav za splošno rabo", Category.CLASS),
        Classification("29.310", "Proizvodnja traktorjev", Category.CLASS),
        Classification("29.320", "Proizvodnja drugih kmetijskih in gozdarskih strojev", Category.CLASS),
        Classification("29.410", "Proizvodnja ročnih prenosnih obdelovalnih strojev", Category.CLASS),
        Classification("29.420", "Proizvodnja drugih strojev za obdelavo kovin", Category.CLASS),
        Classification("29.430", "Proizvodnja drugih obdelovalnih strojev", Category.CLASS),
        Classification("29.510", "Proizvodnja metalurških strojev", Category.CLASS),
        Classification("29.520", "Proizvodnja rudarskih in gradbenih strojev", Category.CLASS),
        Classification("29.530", "Proizvodnja strojev za živilsko in tobačno industrijo", Category.CLASS),
        Classification("29.540", "Proizvodnja strojev za tekstilno, oblačilno in usnjarsko industrijo", Category.CLASS),
        Classification("29.550", "Proizvodnja strojev za industrijo papirja in kartona", Category.CLASS),
        Classification("29.560", "Proizvodnja strojev za druge posebne namene", Category.CLASS),
        Classification("29.600", "Proizvodnja orožja in streliva", Category.CLASS),
        Classification("29.710", "Proizvodnja električnih gospodinjskih strojev", Category.CLASS),
        Classification("29.720", "Proizvodnja neelektričnih gospodinjskih strojev in naprav", Category.CLASS),
        Classification("30.010", "Proizvodnja pisarniških strojev", Category.CLASS),
        Classification("30.020", "Proizvodnja računalnikov in druge opreme za obdelavo podatkov", Category.CLASS),
        Classification("31.100", "Proizvodnja elektromotorjev, generatorjev in transformatorjev", Category.CLASS),
        Classification("31.200", "Proizvodnja naprav za distribucijo in krmiljenje elektrike", Category.CLASS),
        Classification("31.300", "Proizvodnja izoliranih električnih kablov in žic", Category.CLASS),
        Classification("31.400", "Proizvodnja akumulatorjev, primarnih členov in baterij", Category.CLASS),
        Classification("31.500", "Proizvodnja opreme za razsvetljavo in električnih svetilk", Category.CLASS),
        Classification("31.610", "Proizvodnja električne opreme za stroje in vozila", Category.CLASS),
        Classification("31.620", "Proizvodnja druge električne opreme", Category.CLASS),
        Classification(
            "32.100", "Proizvodnja elektronk, elektronskih ventilov in drugih elektronskih komponent", Category.CLASS
        ),
        Classification(
            "32.200",
            "Proizvodnja radijskih in televizijskih oddajnikov, telefonskih in telegrafskih naprav",
            Category.CLASS,
        ),
        Classification(
            "32.300",
            "Proizvodnja radijskih in televizijskih sprejemnikov, naprav in opreme za snemanje in predvajanje zvoka in slike",
            Category.CLASS,
        ),
        Classification(
            "33.100", "Proizvodnja medicinske in kirurške opreme in ortopedskih pripomočkov", Category.CLASS
        ),
        Classification(
            "33.200",
            "Proizvodnja merilnih, kontrolnih, preizkuševalnih, navigacijskih in drugih instrumentov in naprav, razen opreme za industrijsko procesno krmiljenje",
            Category.CLASS,
        ),
        Classification("33.300", "Proizvodnja opreme za industrijsko procesno krmiljenje", Category.CLASS),
        Classification("33.400", "Proizvodnja optičnih instrumentov in fotografske opreme", Category.CLASS),
        Classification("33.500", "Proizvodnja ur", Category.CLASS),
        Classification("34.100", "Proizvodnja motornih vozil", Category.CLASS),
        Classification(
            "34.200", "Proizvodnja karoserij za vozila; proizvodnja prikolic in polprikolic", Category.CLASS
        ),
        Classification(
            "34.300", "Proizvodnja delov in dodatne opreme za motorna vozila in njihove motorje", Category.CLASS
        ),
        Classification("35.110", "Gradnja in popravilo ladij", Category.CLASS),
        Classification("35.120", "Proizvodnja in popravilo čolnov za razvedrilo in šport", Category.CLASS),
        Classification("35.200", "Proizvodnja železniških in drugih tirnih vozil", Category.CLASS),
        Classification("35.300", "Proizvodnja zračnih in vesoljskih plovil", Category.CLASS),
        Classification("35.410", "Proizvodnja motornih koles", Category.CLASS),
        Classification("35.420", "Proizvodnja koles", Category.CLASS),
        Classification("35.430", "Proizvodnja vozil za invalide", Category.CLASS),
        Classification("35.500", "Proizvodnja drugih vozil", Category.CLASS),
        Classification("36.110", "Proizvodnja sedežnega pohištva", Category.CLASS),
        Classification(
            "36.120", "Proizvodnja pohištva za poslovne in prodajne prostore, razen sedežnega", Category.CLASS
        ),
        Classification("36.130", "Proizvodnja kuhinjskega pohištva, razen sedežnega", Category.CLASS),
        Classification("36.140", "Proizvodnja drugega pohištva", Category.CLASS),
        Classification("36.150", "Proizvodnja žimnic", Category.CLASS),
        Classification("36.210", "Kovanje kovancev", Category.CLASS),
        Classification("36.220", "Proizvodnja nakita in podobnih izdelkov", Category.CLASS),
        Classification("36.300", "Proizvodnja glasbil", Category.CLASS),
        Classification("36.400", "Proizvodnja športnih izdelkov", Category.CLASS),
        Classification("36.500", "Proizvodnja igralnih pripomočkov in igrač", Category.CLASS),
        Classification("36.610", "Proizvodnja bižuterije", Category.CLASS),
        Classification("36.620", "Proizvodnja metel in krtač", Category.CLASS),
        Classification("36.630", "Proizvodnja drugih izdelkov", Category.CLASS),
        Classification("37.100", "Reciklaža kovinskih ostankov in odpadkov", Category.CLASS),
        Classification("37.200", "Reciklaža nekovinskih ostankov in odpadkov", Category.CLASS),
        Classification("40.111", "Proizvodnja električne energije v HE", Category.CLASS),
        Classification("40.112", "Proizvodnja električne energije v TE in JE", Category.CLASS),
        Classification("40.113", "Druga proizvodnja električne energije", Category.CLASS),
        Classification("40.120", "Prenos električne energije", Category.CLASS),
        Classification("40.131", "Distribucija električne energije", Category.CLASS),
        Classification("40.132", "Trgovanje z električno energijo", Category.CLASS),
        Classification("40.210", "Proizvodnja plina", Category.CLASS),
        Classification("40.221", "Distribucija plinastih goriv po plinovodni mreži", Category.CLASS),
        Classification("40.222", "Trgovanje s plinastimi gorivi po plinovodni mreži", Category.CLASS),
        Classification("40.300", "Oskrba s paro in toplo vodo", Category.CLASS),
        Classification("41.000", "Zbiranje, čiščenje in distribucija vode", Category.CLASS),
        Classification("45.110", "Rušenje objektov in zemeljska dela", Category.CLASS),
        Classification("45.120", "Raziskovalno vrtanje in sondiranje", Category.CLASS),
        Classification("45.210", "Splošna gradbena dela", Category.CLASS),
        Classification("45.220", "Postavljanje ostrešij in krovska dela", Category.CLASS),
        Classification("45.230", "Gradnja cest, železniških prog, letališč in športnih objektov", Category.CLASS),
        Classification("45.240", "Gradnja vodnih objektov", Category.CLASS),
        Classification("45.250", "Druga gradbena dela, tudi dela specialnih strok", Category.CLASS),
        Classification("45.310", "Električne inštalacije", Category.CLASS),
        Classification("45.320", "Izolacijska dela", Category.CLASS),
        Classification("45.330", "Vodovodne, plinske in sanitarne inštalacije", Category.CLASS),
        Classification("45.340", "Druge inštalacije pri gradnjah", Category.CLASS),
        Classification("45.410", "Fasaderska in štukaterska dela", Category.CLASS),
        Classification("45.420", "Vgrajevanje stavbnega in drugega pohištva", Category.CLASS),
        Classification("45.430", "Oblaganje tal in sten", Category.CLASS),
        Classification("45.441", "Steklarska dela", Category.CLASS),
        Classification("45.442", "Pleskarska dela", Category.CLASS),
        Classification("45.450", "Druga zaključna gradbena dela", Category.CLASS),
        Classification(
            "45.500",
            "Dajanje strojev in naprav za gradnjo in rušenje v najem, skupaj z upravljalci strojev",
            Category.CLASS,
        ),
        Classification("50.101", "Trgovina na debelo z motornimi vozili", Category.CLASS),
        Classification("50.102", "Trgovina na drobno z motornimi vozili", Category.CLASS),
        Classification("50.103", "Posredništvo pri trgovini z motornimi vozili", Category.CLASS),
        Classification("50.200", "Vzdrževanje in popravila motornih vozil", Category.CLASS),
        Classification(
            "50.301", "Trgovina na debelo z rezervnimi deli in dodatno opremo za motorna vozila", Category.CLASS
        ),
        Classification(
            "50.302", "Trgovina na drobno z rezervnimi deli in dodatno opremo za motorna vozila", Category.CLASS
        ),
        Classification(
            "50.303", "Posredništvo pri trgovini z rezervnimi deli in dodatno opremo za motorna vozila", Category.CLASS
        ),
        Classification("50.401", "Trgovina na debelo z motornimi kolesi, deli in opremo", Category.CLASS),
        Classification("50.402", "Trgovina na drobno z motornimi kolesi, deli in opremo", Category.CLASS),
        Classification("50.403", "Posredništvo pri trgovini z motornimi kolesi, deli in opremo", Category.CLASS),
        Classification("50.404", "Vzdrževanje in popravila motornih koles", Category.CLASS),
        Classification("50.501", "Trgovina na drobno z lastnimi motornimi gorivi", Category.CLASS),
        Classification("50.502", "Posredništvo pri trgovini na drobno z motornimi gorivi", Category.CLASS),
        Classification(
            "51.110",
            "Posredništvo pri prodaji kmetijskih surovin, živali, tekstilnih surovin, polizdelkov",
            Category.CLASS,
        ),
        Classification("51.120", "Posredništvo pri prodaji goriv, rud, kovin, tehničnih kemikalij", Category.CLASS),
        Classification("51.130", "Posredništvo pri prodaji lesa in gradbenega materiala", Category.CLASS),
        Classification("51.140", "Posredništvo pri prodaji strojev, industrijske opreme, ladij, letal", Category.CLASS),
        Classification(
            "51.150",
            "Posredništvo pri prodaji pohištva, gospodinjskih predmetov in naprav, drugih  kovinskih izdelkov",
            Category.CLASS,
        ),
        Classification(
            "51.160", "Posredništvo pri prodaji tekstila, oblačil, obutve, usnjenih izdelkov", Category.CLASS
        ),
        Classification("51.170", "Posredništvo pri prodaji živil, pijač, tobačnih izdelkov", Category.CLASS),
        Classification("51.180", "Posredništvo, specializirano za prodajo drugih določenih izdelkov", Category.CLASS),
        Classification("51.190", "Posredništvo pri prodaji raznovrstnih izdelkov", Category.CLASS),
        Classification("51.210", "Trgovina na debelo z žiti, semeni in krmo", Category.CLASS),
        Classification("51.220", "Trgovina na debelo s cvetjem in rastlinami", Category.CLASS),
        Classification("51.230", "Trgovina na debelo z živimi živalmi", Category.CLASS),
        Classification("51.240", "Trgovina na debelo s kožami, usnjem", Category.CLASS),
        Classification("51.250", "Trgovina na debelo s surovim tobakom", Category.CLASS),
        Classification("51.310", "Trgovina na debelo s sadjem in vrtninami", Category.CLASS),
        Classification("51.320", "Trgovina na debelo z mesom in mesnimi izdelki", Category.CLASS),
        Classification(
            "51.330", "Trgovina na debelo z mlekom, mlečnimi izdelki, jajci, jedilnim oljem, maščobami", Category.CLASS
        ),
        Classification("51.340", "Trgovina na debelo z alkoholnimi in brezalkoholnimi pijačami", Category.CLASS),
        Classification("51.350", "Trgovina na debelo s tobačnimi izdelki", Category.CLASS),
        Classification("51.360", "Trgovina na debelo s sladkorjem, čokolado, sladkornimi izdelki", Category.CLASS),
        Classification("51.370", "Trgovina na debelo s kavo, čajem, kakavom, začimbami", Category.CLASS),
        Classification("51.380", "Trgovina na debelo z drugimi živili, tudi z ribami, raki, mehkužci", Category.CLASS),
        Classification(
            "51.390", "Nespecializirana trgovina na debelo z živili, pijačami, tobačnimi izdelki", Category.CLASS
        ),
        Classification("51.410", "Trgovina na debelo s tekstilom", Category.CLASS),
        Classification("51.420", "Trgovina na debelo z oblačili in obutvijo", Category.CLASS),
        Classification(
            "51.430", "Trgovina na debelo z električnimi gospodinjskimi, radijskimi in TV napravami", Category.CLASS
        ),
        Classification("51.440", "Trgovina na debelo s porcelanom, steklenino, tapetami, čistili", Category.CLASS),
        Classification("51.450", "Trgovina na debelo s parfumi in kozmetiko", Category.CLASS),
        Classification(
            "51.460", "Trgovina na debelo s farmacevtskimi izdelki in medicinskimi pripomočki", Category.CLASS
        ),
        Classification("51.470", "Trgovina na debelo z drugimi izdelki široke porabe", Category.CLASS),
        Classification("51.510", "Trgovina na debelo s trdimi, tekočimi in plinastimi gorivi", Category.CLASS),
        Classification("51.520", "Trgovina na debelo s kovinami in rudami", Category.CLASS),
        Classification(
            "51.530", "Trgovina na debelo z lesom, gradbenim materialom in sanitarno opremo", Category.CLASS
        ),
        Classification(
            "51.540",
            "Trgovina na debelo s kovinskimi proizvodi, inštalacijskim materialom, napravami za ogrevanje",
            Category.CLASS,
        ),
        Classification("51.550", "Trgovina na debelo s kemičnimi proizvodi", Category.CLASS),
        Classification("51.560", "Trgovina na debelo z drugimi polizdelki", Category.CLASS),
        Classification("51.570", "Trgovina na debelo z ostanki in odpadki", Category.CLASS),
        Classification("51.810", "Trgovina na debelo z obdelovalnimi stroji", Category.CLASS),
        Classification("51.820", "Trgovina na debelo z gradbenimi stroji", Category.CLASS),
        Classification("51.830", "Trgovina na debelo s stroji za tekstilno industrijo", Category.CLASS),
        Classification("51.840", "Trgovina na debelo z računalniško opremo", Category.CLASS),
        Classification("51.850", "Trgovina na debelo s pisarniškimi stroji in opremo", Category.CLASS),
        Classification("51.860", "Trgovina na debelo z elektronskimi deli in opremo", Category.CLASS),
        Classification(
            "51.870",
            "Trgovina na debelo z drugimi stroji in napravami za industrijo, trgovino, navigacijo",
            Category.CLASS,
        ),
        Classification(
            "51.880", "Trgovina na debelo s kmetijskimi stroji, priključki, kmetijskim orodjem", Category.CLASS
        ),
        Classification("51.900", "Druga trgovina na debelo", Category.CLASS),
        Classification(
            "52.110", "Trgovina na drobno v nespecializiranih prodajalnah, pretežno z živili", Category.CLASS
        ),
        Classification("52.120", "Trgovina na drobno v drugih nespecializiranih prodajalnah", Category.CLASS),
        Classification("52.210", "Trgovina na drobno s svežim sadjem in zelenjavo", Category.CLASS),
        Classification("52.220", "Trgovina na drobno z mesom in mesnimi izdelki", Category.CLASS),
        Classification("52.230", "Trgovina na drobno z ribami, raki, mehkužci", Category.CLASS),
        Classification(
            "52.240", "Trgovina na drobno s kruhom, pecivom, testeninami, sladkornimi izdelki", Category.CLASS
        ),
        Classification("52.250", "Trgovina na drobno z alkoholnimi in brezalkoholnimi pijačami", Category.CLASS),
        Classification("52.260", "Trgovina na drobno s tobačnimi izdelki", Category.CLASS),
        Classification("52.270", "Trgovina na drobno v drugih specializiranih prodajalnah z živili", Category.CLASS),
        Classification("52.310", "Dejavnost lekarn", Category.CLASS),
        Classification("52.320", "Trgovina na drobno z medicinskimi in ortopedskimi izdelki", Category.CLASS),
        Classification("52.330", "Trgovina na drobno s kozmetičnimi in toaletnimi izdelki", Category.CLASS),
        Classification("52.410", "Trgovina na drobno s tekstilom", Category.CLASS),
        Classification("52.420", "Trgovina na drobno z oblačili", Category.CLASS),
        Classification("52.430", "Trgovina na drobno z obutvijo in usnjenimi izdelki", Category.CLASS),
        Classification(
            "52.440", "Trgovina na drobno s pohištvom, svetili in drugimi predmeti za gospodinjstvo", Category.CLASS
        ),
        Classification(
            "52.450", "Trgovina na drobno z električnimi gospodinjskimi, radijskimi in TV napravami", Category.CLASS
        ),
        Classification("52.461", "Trgovina na drobno s kovinskimi izdelki", Category.CLASS),
        Classification("52.462", "Trgovina na drobno z barvami, laki in drugimi kemičnimi sredstvi", Category.CLASS),
        Classification("52.463", "Trgovina na drobno z gradbenim materialom", Category.CLASS),
        Classification("52.471", "Dejavnost knjigarn", Category.CLASS),
        Classification("52.472", "Trgovina na drobno s časopisi, revijami", Category.CLASS),
        Classification("52.473", "Dejavnost papirnic", Category.CLASS),
        Classification("52.481", "Trgovina na drobno s športno opremo", Category.CLASS),
        Classification("52.482", "Dejavnost cvetličarn", Category.CLASS),
        Classification("52.483", "Trgovina na drobno z vrtnarsko opremo in hišnimi živalmi", Category.CLASS),
        Classification("52.484", "Trgovina na drobno s kurivom", Category.CLASS),
        Classification("52.485", "Trgovina na drobno z urami, nakitom, bižuterijo", Category.CLASS),
        Classification("52.486", "Trgovina na drobno z umetniškimi izdelki", Category.CLASS),
        Classification("52.487", "Trgovina na drobno z igračami, otroško opremo", Category.CLASS),
        Classification("52.488", "Trgovina na drobno v drugih specializiranih prodajalnah, d. n.", Category.CLASS),
        Classification("52.500", "Trgovina na drobno z rabljenim blagom", Category.CLASS),
        Classification("52.610", "Trgovina na drobno po pošti", Category.CLASS),
        Classification("52.620", "Trgovina na drobno na tržnicah in stojnicah", Category.CLASS),
        Classification("52.630", "Druga trgovina na drobno zunaj prodajaln", Category.CLASS),
        Classification("52.710", "Popravilo obutve in drugih usnjenih izdelkov", Category.CLASS),
        Classification("52.720", "Popravilo električnih gospodinjskih naprav", Category.CLASS),
        Classification("52.730", "Popravilo ur, nakita", Category.CLASS),
        Classification("52.740", "Druga popravila izdelkov široke porabe", Category.CLASS),
        Classification("55.100", "Dejavnost hotelov in podobnih obratov", Category.CLASS),
        Classification("55.210", "Dejavnost planinskih domov in mladinskih prenočišč", Category.CLASS),
        Classification("55.220", "Dejavnost kampov", Category.CLASS),
        Classification("55.231", "Dejavnost otroških letovišč, počitniških in sindikalnih domov", Category.CLASS),
        Classification("55.232", "Dejavnost turističnih kmetij z nastanitvijo", Category.CLASS),
        Classification("55.233", "Oddajanje sob gospodinjstev gostom", Category.CLASS),
        Classification("55.234", "Dejavnost dijaških, študentskih domov, internatov", Category.CLASS),
        Classification("55.239", "Druge nastanitve za krajši čas", Category.CLASS),
        Classification("55.301", "Dejavnost restavracij in gostiln", Category.CLASS),
        Classification("55.302", "Dejavnost okrepčevalnic, samopostrežnih restavracij", Category.CLASS),
        Classification("55.303", "Dejavnost slaščičarn, kavarn", Category.CLASS),
        Classification("55.304", "Dejavnost premičnih in provizoričnih gostinskih obratov", Category.CLASS),
        Classification("55.305", "Dejavnost turističnih kmetij brez nastanitve", Category.CLASS),
        Classification("55.400", "Točenje pijač", Category.CLASS),
        Classification("55.510", "Dejavnost menz", Category.CLASS),
        Classification("55.520", "Priprava in dostava hrane (catering)", Category.CLASS),
        Classification("60.100", "Železniški promet", Category.CLASS),
        Classification("60.211", "Mestni in primestni potniški promet na rednih linijah", Category.CLASS),
        Classification("60.212", "Medkrajevni potniški cestni promet na rednih linijah", Category.CLASS),
        Classification("60.213", "Dejavnost žičnic, vlečnic", Category.CLASS),
        Classification("60.220", "Dejavnost taksistov", Category.CLASS),
        Classification("60.230", "Drug kopenski potniški promet", Category.CLASS),
        Classification("60.240", "Cestni tovorni promet", Category.CLASS),
        Classification("60.300", "Cevovodni transport", Category.CLASS),
        Classification("61.100", "Pomorski promet", Category.CLASS),
        Classification("61.200", "Promet po rekah, jezerih, prekopih", Category.CLASS),
        Classification("62.100", "Zračni promet na rednih linijah", Category.CLASS),
        Classification("62.200", "Izredni zračni promet", Category.CLASS),
        Classification("63.110", "Prekladanje", Category.CLASS),
        Classification("63.120", "Skladiščenje", Category.CLASS),
        Classification("63.210", "Druge pomožne dejavnosti v kopenskem prometu", Category.CLASS),
        Classification("63.220", "Druge pomožne dejavnosti v vodnem prometu", Category.CLASS),
        Classification("63.230", "Druge pomožne dejavnosti v zračnem prometu", Category.CLASS),
        Classification(
            "63.300",
            "Dejavnost potovalnih agencij in organizatorjev potovanj; s turizmom povezane dejavnosti",
            Category.CLASS,
        ),
        Classification("63.400", "Dejavnost drugih prometnih agencij", Category.CLASS),
        Classification("64.110", "Javna pošta", Category.CLASS),
        Classification("64.120", "Kurirska dejavnost, razen javne pošte", Category.CLASS),
        Classification("64.200", "Telekomunikacije", Category.CLASS),
        Classification("65.110", "Dejavnost centralne banke", Category.CLASS),
        Classification("65.121", "Dejavnost bank", Category.CLASS),
        Classification("65.122", "Dejavnost hranilnic", Category.CLASS),
        Classification("65.210", "Finančni zakup (leasing)", Category.CLASS),
        Classification("65.220", "Drugo kreditiranje", Category.CLASS),
        Classification("65.230", "Drugo finančno posredništvo, d. n.", Category.CLASS),
        Classification("66.010", "Življenjsko zavarovanje", Category.CLASS),
        Classification("66.020", "Dejavnost pokojninskih skladov", Category.CLASS),
        Classification("66.030", "Druga zavarovanja, razen življenjskega", Category.CLASS),
        Classification("67.110", "Dejavnost finančnih trgov", Category.CLASS),
        Classification("67.120", "Posredništvo z vrednostnimi papirji", Category.CLASS),
        Classification("67.130", "Pomožne dejavnosti, povezane s finančnim posredništvom", Category.CLASS),
        Classification("67.200", "Pomožne dejavnosti v zavarovalništvu in pokojninskih skladih", Category.CLASS),
        Classification("70.110", "Organizacija izvedbe nepremičninskih projektov za trg", Category.CLASS),
        Classification("70.120", "Trgovanje z lastnimi nepremičninami", Category.CLASS),
        Classification("70.200", "Dajanje lastnih nepremičnin v najem", Category.CLASS),
        Classification("70.310", "Dejavnost agencij za posredništvo v prometu z nepremičninami", Category.CLASS),
        Classification("70.320", "Upravljanje z nepremičninami za plačilo ali po pogodbi", Category.CLASS),
        Classification("71.100", "Dajanje avtomobilov v najem", Category.CLASS),
        Classification("71.210", "Dajanje drugih kopenskih vozil v najem", Category.CLASS),
        Classification("71.220", "Dajanje ladij  v najem", Category.CLASS),
        Classification("71.230", "Dajanje zračnih plovil v najem", Category.CLASS),
        Classification("71.310", "Dajanje kmetijskih strojev in opreme v najem", Category.CLASS),
        Classification("71.320", "Dajanje gradbenih strojev in opreme v najem", Category.CLASS),
        Classification("71.330", "Dajanje pisarniške in računalniške opreme v najem", Category.CLASS),
        Classification("71.340", "Dajanje drugih strojev in opreme v najem", Category.CLASS),
        Classification("71.401", "Izposojanje športne opreme", Category.CLASS),
        Classification("71.402", "Dejavnost videotek", Category.CLASS),
        Classification("71.403", "Izposojanje drugih izdelkov široke porabe", Category.CLASS),
        Classification("72.100", "Svetovanje o računalniških napravah", Category.CLASS),
        Classification("72.210", "Razvoj in založba programskih paketov", Category.CLASS),
        Classification("72.220", "Oskrba z računalniškimi programi in svetovanje", Category.CLASS),
        Classification("72.300", "Obdelava podatkov", Category.CLASS),
        Classification("72.400", "Omrežne podatkovne storitve", Category.CLASS),
        Classification(
            "72.500",
            "Vzdrževanje in popravila pisarniških in računskih strojev ter računalniških naprav",
            Category.CLASS,
        ),
        Classification("72.600", "Druge računalniške dejavnosti", Category.CLASS),
        Classification("73.101", "Raziskovanje in eksperimentalni razvoj na področju naravoslovja", Category.CLASS),
        Classification("73.102", "Raziskovanje in eksperimentalni razvoj na področju tehnologije", Category.CLASS),
        Classification(
            "73.103",
            "Raziskovanje in eksperimentalni razvoj na področju kmetijstva in sorodnih dejavnosti",
            Category.CLASS,
        ),
        Classification("73.104", "Raziskovanje in eksperimentalni razvoj na področju medicine", Category.CLASS),
        Classification("73.201", "Raziskovanje in eksperimentalni razvoj na področju družboslovja", Category.CLASS),
        Classification("73.202", "Raziskovanje in eksperimentalni razvoj na področju humanistike", Category.CLASS),
        Classification("74.110", "Pravno svetovanje", Category.CLASS),
        Classification(
            "74.120", "Računovodske, knjigovodske in revizijske dejavnosti, davčno svetovanje", Category.CLASS
        ),
        Classification("74.130", "Raziskovanje trga in javnega mnenja", Category.CLASS),
        Classification("74.140", "Podjetniško in poslovno svetovanje", Category.CLASS),
        Classification("74.150", "Dejavnost holdingov", Category.CLASS),
        Classification(
            "74.201",
            "Geodetsko, geološko, geofizikalno, geokemično in drugo opazovanje, meritve, kartiranje",
            Category.CLASS,
        ),
        Classification("74.202", "Prostorsko, urbanistično in krajinsko načrtovanje", Category.CLASS),
        Classification(
            "74.203", "Arhitekturno in gradbeno projektiranje in z njim povezano tehnično svetovanje", Category.CLASS
        ),
        Classification("74.204", "Drugo projektiranje in tehnično svetovanje", Category.CLASS),
        Classification("74.300", "Tehnično preizkušanje in analiziranje", Category.CLASS),
        Classification("74.400", "Oglaševanje", Category.CLASS),
        Classification("74.500", "Dejavnost posredovanja in zaposlovanja delovne sile", Category.CLASS),
        Classification("74.600", "Poizvedovalne dejavnosti in varovanje", Category.CLASS),
        Classification("74.700", "Čiščenje objektov in opreme", Category.CLASS),
        Classification("74.810", "Fotografska dejavnost", Category.CLASS),
        Classification("74.820", "Pakiranje", Category.CLASS),
        Classification("74.851", "Prevajanje", Category.CLASS),
        Classification("74.852", "Fotokopiranje in drugo razmnoževanje", Category.CLASS),
        Classification("74.853", "Druga splošna tajniška opravila", Category.CLASS),
        Classification("74.860", "Dejavnost klicnih centrov", Category.CLASS),
        Classification("74.871", "Prirejanje razstav, sejmov in kongresov", Category.CLASS),
        Classification("74.872", "Oblikovanje, aranžerstvo, dekoraterstvo", Category.CLASS),
        Classification("74.873", "Druge poslovne dejavnosti, d. n.", Category.CLASS),
        Classification("75.110", "Splošna dejavnost javne uprave", Category.CLASS),
        Classification(
            "75.120",
            "Urejanje zdravstva, izobraževanja, kulture in drugih socialnih storitev, razen obveznega socialnega zavarovanja",
            Category.CLASS,
        ),
        Classification("75.130", "Urejanje gospodarskih področij za učinkovitejše poslovanje", Category.CLASS),
        Classification("75.140", "Dejavnost pomožnih služb vlade", Category.CLASS),
        Classification("75.210", "Zunanje zadeve", Category.CLASS),
        Classification("75.220", "Obramba", Category.CLASS),
        Classification("75.230", "Pravosodje", Category.CLASS),
        Classification("75.240", "Javna varnost, zakonitost in red", Category.CLASS),
        Classification("75.250", "Zaščita in reševanje pri požarih in nesrečah", Category.CLASS),
        Classification("75.300", "Obvezno socialno zavarovanje", Category.CLASS),
        Classification("80.101", "Dejavnost vrtcev in predšolsko izobraževanje", Category.CLASS),
        Classification("80.102", "Osnovnošolsko splošno izobraževanje", Category.CLASS),
        Classification("80.103", "Dejavnost zavodov za izobraževanje otrok z motnjami v razvoju", Category.CLASS),
        Classification("80.210", "Srednješolsko splošno izobraževanje", Category.CLASS),
        Classification("80.220", "Srednješolsko poklicno in strokovno izobraževanje", Category.CLASS),
        Classification("80.301", "Višje strokovno izobraževanje", Category.CLASS),
        Classification("80.302", "Visoko strokovno izobraževanje", Category.CLASS),
        Classification("80.303", "Univerzitetno izobraževanje", Category.CLASS),
        Classification("80.410", "Dejavnost vozniških šol", Category.CLASS),
        Classification("80.421", "Dejavnost glasbenih in drugih umetniških šol", Category.CLASS),
        Classification("80.422", "Drugo izobraževanje, izpopolnjevanje in usposabljanje, d. n.", Category.CLASS),
        Classification("85.110", "Bolnišnična zdravstvena dejavnost", Category.CLASS),
        Classification("85.121", "Splošna izvenbolnišnična zdravstvena dejavnost", Category.CLASS),
        Classification("85.122", "Specialistična izvenbolnišnična zdravstvena dejavnost", Category.CLASS),
        Classification("85.130", "Zobozdravstvena dejavnost", Category.CLASS),
        Classification("85.141", "Samostojne zdravstvene dejavnosti, ki jih ne opravljajo zdravniki", Category.CLASS),
        Classification("85.142", "Alternativne oblike zdravljenja", Category.CLASS),
        Classification("85.143", "Druge zdravstvene dejavnosti, d. n.", Category.CLASS),
        Classification("85.200", "Veterinarstvo", Category.CLASS),
        Classification("85.311", "Dejavnost domov za starejše", Category.CLASS),
        Classification("85.319", "Drugo socialno varstvo z nastanitvijo", Category.CLASS),
        Classification("85.321", "Dejavnost centrov za socialno delo", Category.CLASS),
        Classification("85.322", "Dejavnost invalidskih organizacij", Category.CLASS),
        Classification("85.323", "Dejavnost dobrodelnih organizacij", Category.CLASS),
        Classification("85.324", "Dejavnost varstveno delovnih centrov", Category.CLASS),
        Classification("85.329", "Druge socialne dejavnosti", Category.CLASS),
        Classification("90.010", "Ravnanje z odplakami", Category.CLASS),
        Classification("90.021", "Zbiranje in odvoz odpadkov", Category.CLASS),
        Classification(
            "90.022", "Dejavnost deponij, sežiganje in drugi načini odstranjevanja trdnih odpadkov", Category.CLASS
        ),
        Classification("90.023", "Ravnanje z nevarnimi odpadki", Category.CLASS),
        Classification("90.031", "Čiščenje okolja", Category.CLASS),
        Classification("90.032", "Druge dejavnosti javne higiene", Category.CLASS),
        Classification("91.110", "Dejavnost poslovnih in delodajalskih združenj", Category.CLASS),
        Classification("91.120", "Dejavnost strokovnih združenj", Category.CLASS),
        Classification("91.200", "Dejavnost sindikatov", Category.CLASS),
        Classification("91.310", "Dejavnost verskih organizacij", Category.CLASS),
        Classification("91.320", "Dejavnost političnih organizacij", Category.CLASS),
        Classification("91.330", "Dejavnost drugih članskih organizacij", Category.CLASS),
        Classification("92.110", "Snemanje filmov in video filmov", Category.CLASS),
        Classification("92.120", "Distribucija filmov in video filmov", Category.CLASS),
        Classification("92.130", "Kinematografska dejavnost", Category.CLASS),
        Classification("92.200", "Radijska in televizijska dejavnost", Category.CLASS),
        Classification("92.310", "Umetniško ustvarjanje in poustvarjanje", Category.CLASS),
        Classification("92.320", "Obratovanje objektov za kulturne prireditve", Category.CLASS),
        Classification("92.330", "Dejavnost sejmišč in zabaviščnih parkov", Category.CLASS),
        Classification("92.340", "Druge razvedrilne dejavnosti", Category.CLASS),
        Classification("92.400", "Dejavnost tiskovnih agencij", Category.CLASS),
        Classification("92.511", "Dejavnost knjižnic", Category.CLASS),
        Classification("92.512", "Dejavnost arhivov", Category.CLASS),
        Classification("92.521", "Dejavnost muzejev", Category.CLASS),
        Classification("92.522", "Varstvo kulturne dediščine", Category.CLASS),
        Classification("92.530", "Dejavnost botaničnih in živalskih vrtov ter naravnih rezervatov", Category.CLASS),
        Classification("92.610", "Obratovanje športnih objektov", Category.CLASS),
        Classification("92.621", "Dejavnost marin", Category.CLASS),
        Classification("92.622", "Dejavnost smučarskih centrov in smučišč", Category.CLASS),
        Classification("92.623", "Druge športne dejavnosti", Category.CLASS),
        Classification("92.711", "Prirejanje klasičnih iger na srečo", Category.CLASS),
        Classification("92.712", "Dejavnost igralnic", Category.CLASS),
        Classification("92.720", "Druge dejavnosti za sprostitev, d. n.", Category.CLASS),
        Classification("93.010", "Dejavnost pralnic in kemičnih čistilnic", Category.CLASS),
        Classification("93.021", "Frizerska dejavnost", Category.CLASS),
        Classification("93.022", "Kozmetična dejavnost", Category.CLASS),
        Classification("93.023", "Pedikerska dejavnost", Category.CLASS),
        Classification("93.030", "Pogrebna dejavnost", Category.CLASS),
        Classification("93.040", "Dejavnost salonov za nego telesa", Category.CLASS),
        Classification("93.050", "Druge osebne storitve", Category.CLASS),
        Classification("95.000", "Zasebna gospodinjstva z zaposlenim osebjem", Category.CLASS),
        Classification("99.000", "Eksteritorialne organizacije in združenja", Category.CLASS),
        Classification("15.810", "Proizvodnja kruha,svežega peciva in slaščic", Category.CLASS),
        Classification("20.100", "Žaganje in skobljanje lesa ter impregniranje", Category.CLASS),
    ],
)
